@@ -26,12 +26,13 @@
 import os
 import re
 import traceback
+from pickle import UnpicklingError
 
 # PySol imports
 from pysollib.mfxutil import destruct, Struct
-from pysollib.mfxutil import pickle, unpickle, UnpicklingError
+from pysollib.mfxutil import pickle, unpickle
 from pysollib.mfxutil import getusername, getprefdir
-from pysollib.mfxutil import latin1_to_ascii, print_err
+from pysollib.mfxutil import latin1_normalize, print_err
 from pysollib.mfxutil import USE_PIL
 from pysollib.util import CARDSET, IMAGE_EXTENSIONS
 from pysollib.settings import PACKAGE, VERSION_TUPLE, WIN_SYSTEM
@@ -836,6 +837,9 @@ class Application:
         else:
             size = 'small'
         style = self.opt.toolbar_style
+        if TOOLKIT == 'kivy':
+            size = 'xlarge'
+            style = 'bluecurve'
         d = self._getImagesDir('toolbar', style, size)
         if d:
             return d
@@ -1263,11 +1267,7 @@ Please select a %s type %s.
             return None
         if gi.rules_filename is not None:
             return gi.rules_filename
-        n = gi.en_name                  # english name
-        # n = re.sub(r"[\[\(].*$", "", n)
-        n = latin1_to_ascii(n)
-        n = re.sub(r"[^\w]", "", n)
-        n = n.lower() + ".html"
+        n = latin1_normalize(gi.en_name) + '.html'        # english name
         f = os.path.join(self.dataloader.dir, "html", "rules", n)
         if not os.path.exists(f):
             n = ''
@@ -1277,18 +1277,10 @@ Please select a %s type %s.
     def getGameSaveName(self, id):
         if os.path.supports_unicode_filenames:  # new in python 2.3
             return self.getGameTitleName(id)
-        gi = self.gdb.get(id)
-        n = gi.en_name                  # english name
+        n = self.gdb.get(id).en_name                  # english name
         if not n:
             return None
-        #         m = re.search(r"^(.*)([\[\(](\w+).*[\]\)])\s*$", n)
-        #          if m:
-        #              n = m.group(1) + "_" + m.group(2).lower()
-        n = latin1_to_ascii(n)
-        n = n.lower()
-        n = re.sub(r"[\s]", "_", n)
-        n = re.sub(r"[^\w]", "", n)
-        return n
+        return re.sub(r"[\s]", "_", latin1_normalize(n))
 
     def getRandomGameId(self, games=None):
         if games is None:
@@ -1462,7 +1454,7 @@ Please select a %s type %s.
         # find all available cardsets
         dirs = manager.getSearchDirs(self, ("cardsets", ""), "PYSOL_CARDSETS")
         if DEBUG:
-            dirs = dirs + manager.getSearchDirs(self, "cardsets-*")
+            dirs += manager.getSearchDirs(self, "cardsets-*")
         # print dirs
         found, t = [], {}
         fnames = {}  # (to check for duplicates)
