@@ -723,7 +723,7 @@ class Demon(Canfield):
 class CanfieldRush_Talon(WasteTalonStack):
     def dealCards(self, sound=False):
         self.num_deal = 4-self.round
-        WasteTalonStack.dealCards(self, sound=sound)
+        return WasteTalonStack.dealCards(self, sound=sound)
 
 
 class CanfieldRush(Canfield):
