@@ -32,6 +32,7 @@ from io import BytesIO
 
 # PySol imports
 from pysollib.settings import DEBUG, FCS_COMMAND
+from pysollib.pysolrandom import constructRandom
 from pysollib.mfxutil import destruct
 from pysollib.util import KING
 
@@ -419,7 +420,7 @@ class DefaultHint(AbstractHint):
         else:
             d = (c.rank - t.cap.base_rank) % t.cap.mod
             if d > t.cap.mod // 2:
-                d = d - t.cap.mod
+                d -= t.cap.mod
         if abs(d) <= 1:
             # drop Ace and 2 immediately
             score = 92000
@@ -551,7 +552,7 @@ class DefaultHint(AbstractHint):
                     if stack and stack is not r:
                         assert ncards == 1
                         drop_info.append((c, stack, ncards, i))
-                    i = i + 1
+                    i += 1
                 # now try to make a move so that the drop-card will get free
                 for di in drop_info:
                     c = di[0]
@@ -565,7 +566,7 @@ class DefaultHint(AbstractHint):
                             continue
                         # print "drop move", r, t, sub_pile
                         score = 40000
-                        score = score + 1000 + (self.K - r.getCard().rank)
+                        score += 1000 + (self.K - r.getCard().rank)
                         # force the drop (to avoid loops)
                         force = (999999, 0, di[2], r, di[1], self.BLUE, None)
                         self.addHint(
@@ -716,6 +717,18 @@ class SpiderType_Hint(DefaultHint):
     pass
 
 
+class PySolHintLayoutImportError(Exception):
+
+    def __init__(self, msg, cards, line_num):
+        """docstring for __init__"""
+        self.msg = msg
+        self.cards = cards
+        self.line_num = line_num
+
+    def format(self):
+        return self.msg + ":\n\n" + ', '.join(self.cards)
+
+
 # ************************************************************************
 # * FreeCell-Solver
 # ************************************************************************
@@ -744,18 +757,21 @@ class Base_Solver_Hint:
     def config(self, **kw):
         self.options.update(kw)
 
-    def _card2str_format(self, fmt, card):
+    def _card2str_format(self, fmt, rank, suit):
         # row and reserves
-        rank = (card.rank-self.base_rank) % 13
-        return fmt % {'R': "A23456789TJQK"[rank], 'S': "CSHD"[card.suit]}
+        rank = (rank-self.base_rank) % 13
+        return fmt % {'R': "A23456789TJQK"[rank], 'S': "CSHD"[suit]}
+
+    def card2str1_(self, rank, suit):
+        # row and reserves
+        return self._card2str_format('%(R)s%(S)s', rank, suit)
 
     def card2str1(self, card):
-        # row and reserves
-        return self._card2str_format('%(R)s%(S)s', card)
+        return self.card2str1_(card.rank, card.suit)
 
     def card2str2(self, card):
         # foundations
-        return self._card2str_format('%(S)-s%(R)s', card)
+        return self._card2str_format('%(S)s-%(R)s', card.rank, card.suit)
 
 # hard solvable: Freecell #47038300998351211829 (65539 iters)
 
@@ -839,9 +855,12 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
 
     def importFile(solver, fh, s_game, self):
         s_game.endGame()
+        s_game.random = constructRandom('Custom')
         s_game.newGame(
             shuffle=True,
+            random=constructRandom('Custom'),
             dealer=lambda: solver.importFileHelper(fh, s_game))
+        s_game.random = constructRandom('Custom')
 
     def importFileHelper(solver, fh, s_game):
         game = s_game.s
@@ -849,10 +868,11 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
 
         RANKS_S = "A23456789TJQK"
         RANKS0_S = '0' + RANKS_S
-        RANKS_RE = '[' + RANKS_S + ']'
+        RANKS_RE = '(?:' + '[' + RANKS_S + ']' + '|10)'
         SUITS_S = "CSHD"
         SUITS_RE = '[' + SUITS_S + ']'
         CARD_RE = r'(?:' + RANKS_RE + SUITS_RE + ')'
+        line_num = 0
 
         def cards():
             return game.talon.cards
@@ -860,7 +880,13 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
         def put(target, suit, rank):
             ret = [i for i, c in enumerate(cards())
                    if c.suit == suit and c.rank == rank]
-            assert len(ret) == 1
+            if len(ret) < 1:
+                raise PySolHintLayoutImportError(
+                    "Duplicate cards in input",
+                    [solver.card2str1_(rank, suit)],
+                    line_num
+                )
+
             ret = ret[0]
             game.talon.cards = \
                 cards()[0:ret] + cards()[(ret+1):] + [cards()[ret]]
@@ -868,29 +894,55 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
             s_game.moveMove(1, game.talon, target, frames=0)
 
         def put_str(target, str_):
-            put(target, SUITS_S.index(str_[1]), RANKS_S.index(str_[0]))
+            put(target, SUITS_S.index(str_[-1]),
+                (RANKS_S.index(str_[0]) if len(str_) == 2 else 9))
 
-        def my_find_re(RE, m):
+        def my_find_re(RE, m, msg):
             s = m.group(1)
-            assert re.match(r'^\s*(?:' + RE + r')?(?:\s+' + RE + r')*\s*$', s)
+            if not re.match(r'^\s*(?:' + RE + r')?(?:\s+' + RE + r')*\s*$', s):
+                raise PySolHintLayoutImportError(
+                    msg,
+                    [],
+                    line_num
+                )
             return re.findall(r'\b' + RE + r'\b', s)
 
-        for line_p in fh:
+        # Based on https://stackoverflow.com/questions/8898294 - thanks!
+        def mydecode(s):
+            if sys.version_info < (3,):
+                pass  # return s
+            for encoding in "utf-8-sig", "utf-8":
+                try:
+                    return s.decode(encoding)
+                except UnicodeDecodeError:
+                    continue
+            return s.decode("latin-1")  # will always work
+
+        mytext = mydecode(fh.read())
+        for line_p in mytext.splitlines():
+            line_num += 1
             line = line_p.rstrip('\r\n')
             m = re.match(r'^(?:Foundations:|Founds?:)\s*(.*)', line)
             if m:
                 for gm in my_find_re(
-                        r'(' + SUITS_RE + r')-([' + RANKS0_S + r'])', m):
+                        r'(' + SUITS_RE + r')-([' + RANKS0_S + r'])', m,
+                        "Invalid Foundations line"):
                     for foundat in game.foundations:
                         suit = foundat.cap.suit
                         if SUITS_S[suit] == gm[0]:
-                            for r in range(RANKS0_S.index(gm[1])):
+                            rank = gm[1]
+                            if len(rank) == 1:
+                                lim = RANKS0_S.index(rank)
+                            else:
+                                lim = 10
+                            for r in range(lim):
                                 put(foundat, suit, r)
                             break
                 continue
             m = re.match(r'^(?:FC:|Freecells:)\s*(.*)', line)
             if m:
-                g = my_find_re(r'(' + CARD_RE + r'|\-)', m)
+                g = my_find_re(r'(' + CARD_RE + r'|\-)', m,
+                               "Invalid Freecells line")
                 while len(g) < len(game.reserves):
                     g.append('-')
                 for i, gm in enumerate(g):
@@ -899,12 +951,17 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
                         put_str(game.reserves[i], str_)
                 continue
             m = re.match(r'^:?\s*(.*)', line)
-            assert m
-            for str_ in my_find_re(r'(' + CARD_RE + r')', m):
+            for str_ in my_find_re(r'(' + CARD_RE + r')', m,
+                                   "Invalid column text"):
                 put_str(game.rows[stack_idx], str_)
 
             stack_idx += 1
-        assert len(cards()) == 0
+        if len(cards()) > 0:
+            raise PySolHintLayoutImportError(
+                "Missing cards in input",
+                [solver.card2str1(c) for c in cards()],
+                -1
+            )
 
     def calcBoardString(self):
         game = self.game
@@ -1144,20 +1201,13 @@ class BlackHoleSolver_Hint(Base_Solver_Hint):
             if DEBUG >= 5:
                 print(s)
 
-            m = re.search('^(Intractable!|Unsolved!|Solved!)', s.rstrip())
+            m = re.search('^(Intractable|Unsolved|Solved)!', s.rstrip())
             if m:
                 result = m.group(1)
                 break
+
         self.dialog.setText(iter=iter_, depth=depth, states=states)
-
-        if (result == 'Intractable!'):
-            self.solver_state = 'intractable'
-            return
-        if (result == 'Unsolved!'):
-            self.solver_state = 'unsolved'
-            return
-
-        self.solver_state = 'solved'
+        self.solver_state = result.lower()
 
         hints = []
         for sbytes in pout:
