@@ -23,45 +23,32 @@
 
 # imports
 # import os
-from UserList import UserList
+from six.moves import UserList
 
 # PySol imports
-# from pysollib.mygettext import _, n_
 from pysollib.mygettext import _
-# from pysollib.mfxutil import destruct, Struct, KwStruct
-# from pysollib.mfxutil import format_time
 from pysollib.gamedb import GI
-# from pysollib.help import help_html
-# from pysollib.resource import CSI
 
 # Toolkit imports
-# from tkutil import unbind_destroy
-# from tkwidget import MfxDialog, MfxScrolledCanvas
-from selecttree import SelectDialogTreeLeaf, SelectDialogTreeNode
-from selecttree import SelectDialogTreeData  # , SelectDialogTreeCanvas
+from pysollib.kivy.selecttree import SelectDialogTreeLeaf, SelectDialogTreeNode
+from pysollib.kivy.selecttree import SelectDialogTreeData
+from pysollib.kivy.LApp import LScrollView
+from pysollib.kivy.LApp import LTopLevel
+from pysollib.kivy.LApp import LTreeNode
+from pysollib.kivy.LApp import LTreeRoot
 
 # Kivy imports
-# from kivy.uix.treeview import TreeView
-# from kivy.uix.treeview import TreeViewLabel
-# from kivy.uix.treeview import TreeViewNode
-# from kivy.uix.label import Label
-# from kivy.uix.button import Button
-# from kivy.uix.behaviors import ButtonBehavior
-# from kivy.uix.scrollview import ScrollView
 from kivy.clock import Clock
 
-from LApp import LScrollView
-from LApp import LTopLevel
-from LApp import LTreeNode
-from LApp import LTreeRoot
-
 
 # ************************************************************************
 # * Nodes
 # ************************************************************************
 
+
 class SelectGameLeaf(SelectDialogTreeLeaf):
-    pass
+    def getContents(self):
+        return None
 
 
 class SelectGameNode(SelectDialogTreeNode):
@@ -74,7 +61,6 @@ class SelectGameNode(SelectDialogTreeNode):
                     node = SelectGameLeaf(self.tree, self, name, key=id)
                     contents.append(node)
         else:
-            # for gi in self.tree.data.all_games_gi:
             for gi in self.tree.all_games_gi:
                 if gi and self.select_func is None:
                     # All games
@@ -86,7 +72,7 @@ class SelectGameNode(SelectDialogTreeNode):
                     name = gi.name
                     node = SelectGameLeaf(self.tree, self, name, key=gi.id)
                     contents.append(node)
-        return contents or self.tree.data.no_games
+        return contents or self.tree.no_games
 
 
 # ************************************************************************
@@ -98,7 +84,8 @@ class SelectGameData(SelectDialogTreeData):
         SelectDialogTreeData.__init__(self)
 
         # originale.
-        self.all_games_gi = map(app.gdb.get, app.gdb.getGamesIdSortedByName())
+        self.all_games_gi = list(
+            map(app.gdb.get, app.gdb.getGamesIdSortedByName()))
         self.no_games = [SelectGameLeaf(None, None, _("(no games)"), None), ]
         #
         s_by_type = s_oriental = s_special = None
@@ -205,7 +192,7 @@ class SelectGameData(SelectDialogTreeData):
         ul_alternate_names = UserList(
             list(app.gdb.getGamesTuplesSortedByAlternateName()))
         #
-        self.rootnodes = filter(None, (
+        self.rootnodes = [_f for _f in (
             # SelectGameNode(None, _("All Games"), None),
             SelectGameNode(None, _("Popular Games"),
                            lambda gi: gi.si.game_flags & GI.GT_POPULAR),
@@ -294,7 +281,7 @@ class SelectGameData(SelectDialogTreeData):
             )),
             s_original,
             s_contrib,
-        ))
+        ) if _f]
 
 
 # ************************************************************************
