@@ -23,24 +23,24 @@
 
 # imports
 import os
-import htmllib
+import sys
+# import htmllib
+import pysollib.htmllib2 as htmllib
 import formatter
 
 # PySol imports
 from pysollib.mygettext import _
-from pysollib.pysoltk import bind, unbind_destroy
 from pysollib.mfxutil import Struct, openURL
 from pysollib.settings import TITLE
 from pysollib.kivy.LApp import LTopLevel
 from pysollib.kivy.LApp import LScrollView
+from pysollib.kivy.LApp import LPopCommander
+from pysollib.kivy.LApp import get_platform
 from pysollib.pysoltk import MfxMessageDialog
 
 from kivy.uix.boxlayout import BoxLayout
 from kivy.uix.label import Label
 from kivy.uix.button import Button
-# from kivy.uix.behaviors import ButtonBehavior
-# from kivy.uix.scrollview import ScrollView
-# from kivy.clock import Clock
 
 REMOTE_PROTOCOLS = ("ftp:", "gopher:", "http:", "mailto:", "news:", "telnet:")
 
@@ -49,6 +49,39 @@ REMOTE_PROTOCOLS = ("ftp:", "gopher:", "http:", "mailto:", "news:", "telnet:")
 # ************************************************************************
 
 
+if get_platform() == 'android':
+    from jnius import autoclass
+    from jnius import cast
+
+    def startAndroidBrowser(www):
+        # init java classes
+        PythonActivity = autoclass('org.kivy.android.PythonActivity')
+        Intent = autoclass('android.content.Intent')
+        Uri = autoclass('android.net.Uri')
+        # String = autoclass('java.lang.String') # get the Java object
+
+        # prepare activity
+        # PythonActivity.mActivity is the instance of the current Activity
+        # BUT, startActivity is a method from the Activity class, not from our
+        # PythonActivity.
+        # We need to cast our class into an activity and use it
+        currentActivity = cast(
+            'android.app.Activity', PythonActivity.mActivity)
+
+        # create the intent
+        intent = Intent()
+        intent.setAction(Intent.ACTION_VIEW)
+        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
+        intent.setDataAndType(Uri.parse(www), "application/xhtml+xml")
+
+        # start activity
+        currentActivity.startActivity(intent)
+
+# ************************************************************************
+# *
+# ************************************************************************
+
+
 def cmp2(a, b):
     """python 3 replacement for python 2 cmp function"""
     return (a > b) - (a < b)
@@ -95,6 +128,7 @@ class tkHTMLWriter(formatter.NullWriter):
         self.indent = ""
         self.text.label.bind(on_ref_press=self.refpress)
 
+    '''
     def createCallback(self, href):
         class Functor:
             def __init__(self, viewer, arg):
@@ -105,13 +139,14 @@ class tkHTMLWriter(formatter.NullWriter):
                 self.viewer.updateHistoryXYView()
                 return self.viewer.display(self.arg)
         return Functor(self.viewer, href)
+    '''
 
     def write(self, data):
-        print('writer: write %s' % data)
+        # print('writer: write %s' % data)
         self.text.insert("insert", data)
 
     def anchor_bgn(self, href, name, type):
-        print('writer: anchor_bgn %s - %s' % (href, name))
+        # print('writer: anchor_bgn %s - %s' % (href, name))
         if href:
             # self.text.update_idletasks()   # update display during parsing
             self.anchor = (href, name, type)
@@ -127,10 +162,11 @@ class tkHTMLWriter(formatter.NullWriter):
             # self.text.tag_config(tag, foreground=fg, underline=1)
 
     def refpress(self, instance, value):
-        print('writer: refpress %s, %s' % (instance, value))
+        # print('writer: refpress %s, %s' % (instance, value))
+        pass
 
     def anchor_end(self):
-        print('writer: anchor_end')
+        # print('writer: anchor_end')
         if self.anchor:
 
             self.anchor = None
@@ -147,7 +183,7 @@ class tkHTMLWriter(formatter.NullWriter):
         self.text.config(cursor=self.viewer.defcursor)
 
     def new_font(self, font):
-        print('writer: new_font %s' % str(font))
+        # print('writer: new_font %s' % str(font))
         # end the current font
         if self.font:
             # print "end_font(%s)" % `self.font`
@@ -169,11 +205,11 @@ class tkHTMLWriter(formatter.NullWriter):
                 self.font = None
 
     def new_margin(self, margin, level):
-        print('writer: new_margin %s, %s' % (margin, level))
+        # print('writer: new_margin %s, %s' % (margin, level))
         self.indent = "    " * level
 
     def send_label_data(self, data):
-        print('writer: send_label_data %s' % (data))
+        # print('writer: send_label_data %s' % (data))
         # self.write(self.indent + data + " ")
         self.write(self.indent)
         if data == '*':  # <li>
@@ -188,34 +224,35 @@ class tkHTMLWriter(formatter.NullWriter):
         self.write(' ')
 
     def send_paragraph(self, blankline):
-        print('writer: send_paragraph %s' % (blankline))
+        # print('writer: send_paragraph %s' % (blankline))
         self.write('\n' * blankline)
 
     def send_line_break(self):
-        print('writer: send_break')
+        # print('writer: send_break')
         self.write('\n')
 
     def send_hor_rule(self, *args):
         if (args):
-            print('writer: send_hor_rule %s' % (args))
+            pass
+            # print('writer: send_hor_rule %s' % (args))
         # width = int(int(self.text["width"]) * 0.9)
         width = 20
         self.write("_" * width)
         self.write("\n")
 
     def send_literal_data(self, data):
-        print('writer: send_literal_data %s' % (data))
+        # print('writer: send_literal_data %s' % (data))
         self.write(data)
 
     def send_flowing_data(self, data):
-        print('writer: send_flowing_data %s' % (data))
+        # print('writer: send_flowing_data %s' % (data))
         self.write(data)
 
-
 # ************************************************************************
 # *
 # ************************************************************************
 
+
 class tkHTMLParser(htmllib.HTMLParser):
     def anchor_bgn(self, href, name, type):
         self.formatter.flush_softspace()
@@ -223,13 +260,13 @@ class tkHTMLParser(htmllib.HTMLParser):
         self.formatter.writer.anchor_bgn(href, name, type)
 
     def close(self):
-        print('tkHTMLParser1: close()')
+        # print('tkHTMLParser1: close()')
         self.formatter.writer.text.applyBuffer()
-        label = self.formatter.writer.text.label
-        print('tkHTMLParser: label.refs %s' % str(label.refs))
+        # label = self.formatter.writer.text.label
+        # print('tkHTMLParser: label.refs %s' % str(label.refs))
         # print ('tkHTMLParser: label.refs %s' % str(Label.refs))
 
-        print('tkHTMLParser2: close()')
+        # print('tkHTMLParser2: close()')
         htmllib.HTMLParser.close(self)
 
     def anchor_end(self):
@@ -273,7 +310,7 @@ class HTMLLabel(Label):
         self.height = self.texture_size[1]
 
 
-class HTMLText(LScrollView):
+class HTMLText(LScrollView, LPopCommander):
     def __init__(self, **kw):
         super(HTMLText, self).__init__(**kw)
 
@@ -283,11 +320,11 @@ class HTMLText(LScrollView):
         self.add_widget(self.label)
 
     def applyBuffer(self):
-        print('applybuffer:')
+        # print('applybuffer:')
         self.label.text = self.textbuffer
 
     def config(self, **kw):
-        print('config: %s' % kw)
+        # print('config: %s' % kw)
         pass
 
     def update_idletasks(self):
@@ -303,16 +340,16 @@ class HTMLText(LScrollView):
         pass
 
     def index(self, cmd):
-        print('index: %s' % cmd)
+        # print('index: %s' % cmd)
         # was sollen wir hier zuruckgeben ?
         return 0
 
     def tag_add(self, font, fontmark, cmd):
-        print('tag_add: %s, %s, %s' % (font, fontmark, cmd))
+        # print('tag_add: %s, %s, %s' % (font, fontmark, cmd))
         pass
 
     def tag_config(self, tag, **kw):
-        print('tag_config: %s, %s' % (tag, kw))
+        # print('tag_config: %s, %s' % (tag, kw))
         # self.tags[tag] = kw
 
         # for t, k in self.tags:
@@ -321,11 +358,11 @@ class HTMLText(LScrollView):
         pass
 
     def xview_moveto(self, xview):
-        print('xview_moveto: %s' % xview)
+        # print('xview_moveto: %s' % xview)
         pass
 
     def yview_moveto(self, yview):
-        print('yview_moveto: %s' % yview)
+        # print('yview_moveto: %s' % yview)
         pass
 
 
@@ -335,10 +372,26 @@ class HTMLViewer:
 
     def make_pop_command(self, parent, title):
         def pop_command(event):
-            print('event = %s' % event)
+            if self.history.index > 1:
+                self.goBack(event)
+                return None
+            del self.history.list
+            self.history.index = 0
             parent.popWork(title)
         return pop_command
 
+    def make_close_command(self, parent, title):
+        def close_command(event):
+            del self.history.list
+            self.history.index = 0
+            parent.popWork(title)
+        return close_command
+
+    def refpress(self, instance, value):
+        # print('writer: refpress %s, %s' % (instance, value))
+        self.updateHistoryXYView()
+        return self.display(value)
+
     def __init__(self, parent, app=None, home=None):
         self.parent = parent
         self.app = app
@@ -366,11 +419,12 @@ class HTMLViewer:
             parent.popWork(self.title)
 
         pc = self.make_pop_command(parent, self.title)
+        cc = self.make_close_command(parent, self.title)
 
         # neuen Dialog aufbauen.
 
         window = LTopLevel(app.top, self.title, size_hint=(1.8, 1.0))
-        window.titleline.bind(on_press=pc)
+        window.titleline.bind(on_press=cc)
         self.parent.pushWork(self.title, window)
         self.window = window
         self.running = True
@@ -415,9 +469,9 @@ class HTMLViewer:
 
         # create text widget
 
-        self.text = HTMLText(text="hallo", size_hint=(1.0, 1.0))
-        # textouter = BoxLayout(size_hint=(1.0, 1.0))
-        # textouter.add_widget(self.text)
+        self.text = HTMLText(
+            pop_command=pc, text="hallo", size_hint=(1.0, 1.0))
+        self.text.label.bind(on_ref_press=self.refpress)
         content.add_widget(self.text)
         '''
         text_frame = Tkinter.Frame(parent)
@@ -447,33 +501,6 @@ class HTMLViewer:
         for name, fn in self.symbols_fn.items():
             self.symbols_img[name] = self.getImage(fn)
 
-        # self.initBindings()
-
-    def initBindings(self):
-        w = self.parent
-        bind(w, "WM_DELETE_WINDOW", self.destroy)
-        bind(w, "<Escape>", self.destroy)
-        bind(w, "<KeyPress-Prior>", self.page_up)
-        bind(w, "<KeyPress-Next>", self.page_down)
-        bind(w, "<KeyPress-Up>", self.unit_up)
-        bind(w, "<KeyPress-Down>", self.unit_down)
-        bind(w, "<KeyPress-Begin>", self.scroll_top)
-        bind(w, "<KeyPress-Home>", self.scroll_top)
-        bind(w, "<KeyPress-End>", self.scroll_bottom)
-        bind(w, "<KeyPress-BackSpace>", self.goBack)
-
-    def destroy(self, *event):
-        unbind_destroy(self.parent)
-        try:
-            self.parent.wm_withdraw()
-        except Exception:
-            pass
-        try:
-            self.parent.destroy()
-        except Exception:
-            pass
-        self.parent = None
-
     def _yview(self, *args):
         self.text.yview(*args)
         return 'break'
@@ -531,6 +558,9 @@ class HTMLViewer:
         if url[-1:] == "/" or os.path.isdir(url):
             url = os.path.join(url, "index.html")
         url = os.path.normpath(url)
+        if sys.version_info > (3,):
+            import codecs
+            return codecs.open(url, encoding='utf-8'), url
         return open(url, "rb"), url
 
     def display(self, url, add=1, relpath=1, xview=0, yview=0):
@@ -545,7 +575,11 @@ class HTMLViewer:
         # far too limited to display anything but our documentation...
         for p in REMOTE_PROTOCOLS:
             if url.startswith(p):
-                if not openURL(url):
+                plat = get_platform()
+                if plat == 'android':
+                    print("Open url: %s (TBD)" % url)
+                    startAndroidBrowser(url)
+                elif not openURL(url):
                     return
 
         # locate the file relative to the current url
@@ -563,9 +597,13 @@ class HTMLViewer:
             file.close()
             file = None
         except Exception:
+            print("Open url(1) - Exception: %s" % url)
             if file:
                 file.close()
+
+            '''
             self.errorDialog(_("Unable to service request:\n") + url)
+            '''
             return
 
         self.url = url
@@ -593,6 +631,7 @@ class HTMLViewer:
         self.text.config(state="normal")
         self.text.delete("1.0", "end")
         # self.images = {}
+        self.text.textbuffer = ''
         writer = tkHTMLWriter(self.text, self, self.app)
         fmt = formatter.AbstractFormatter(writer)
         parser = tkHTMLParser(fmt)
@@ -625,8 +664,6 @@ class HTMLViewer:
     def updateHistoryXYView(self):
         if self.history.index > 0:
             url, xview, yview = self.history.list[self.history.index - 1]
-            xview = self.text.xview()[0]
-            yview = self.text.yview()[0]
             self.history.list[self.history.index - 1] = (url, xview, yview)
 
     def goBack(self, *event):
@@ -660,14 +697,6 @@ class HTMLViewer:
             return self.images[fn]
         else:
             return None
-        '''
-        try:
-            img = Tkinter.PhotoImage(master=self.parent, file=fn)
-        except:
-            img = None
-        self.images[fn] = img
-        return img
-        '''
 
     def showImage(self, src, alt, ismap, align, width, height):
         url = self.basejoin(src)
@@ -676,26 +705,8 @@ class HTMLViewer:
             self.text.image_create(index="insert", image=img, padx=0, pady=0)
 
 
-''
-
 # ************************************************************************
 # *
 # ************************************************************************
 
-'''
-def tkhtml_main(args):
-    try:
-        url = args[1]
-    except:
-        url = os.path.join(os.pardir, os.pardir, "data", "html", "index.html")
-    top = Tkinter.Tk()
-    top.wm_minsize(400, 200)
-    viewer = HTMLViewer(top)
-    viewer.app = None
-    viewer.display(url)
-    top.mainloop()
-    return 0
-
-if __name__ == "__main__":
-    sys.exit(tkhtml_main(sys.argv))
-'''
+''
