@@ -69,60 +69,6 @@ class MfxDialog:  # ex. _ToplevelDialog
         self.accel_keys = {}
         self.top = makeToplevel(parent, title=title)
 
-    '''
-    def mainloop(self, focus=None, timeout=0, transient=True):
-        bind(self.top, "<Escape>", self.mCancel)
-        bind(self.top, '<Alt-Key>', self.altKeyEvent)  # for accelerators
-        if focus is not None:
-            focus.focus()
-        if transient:
-            setTransient(self.top, self.parent)
-            try:
-                self.top.grab_set()
-            except Tkinter.TclError:
-                if traceback:
-                    traceback.print_exc()
-                pass
-            if timeout > 0:
-                self.timer = after(self.top, timeout, self.mTimeout)
-            try:
-                self.top.mainloop()
-            except SystemExit:
-                pass
-            self.destroy()
-
-    def destroy(self):
-        after_cancel(self.timer)
-        unbind_destroy(self.top)
-        try:
-            self.top.wm_withdraw()
-        except:
-            if traceback:
-                traceback.print_exc()
-            pass
-        try:
-            self.top.destroy()
-        except:
-            if traceback:
-                traceback.print_exc()
-            pass
-        # destruct(self.top)
-        if 1 and self.parent:  # ???
-            try:
-                # self.parent.update_idletasks()
-                # FIXME: why do we need this under Windows ?
-                if hasattr(self.parent, "busyUpdate"):
-                    self.parent.busyUpdate()
-                else:
-                    self.parent.update()
-            except:
-                if traceback:
-                    traceback.print_exc()
-                pass
-        self.top = None
-        self.parent = None
-    '''
-
     def wmDeleteWindow(self, *event):
         self.status = 1
         raise SystemExit
@@ -170,104 +116,6 @@ class MfxDialog:  # ex. _ToplevelDialog
         a = LBoxLayout(orientation="vertical")
         b = LBoxLayout(orientation="vertical")
         return a, b
-        '''
-        bottom_frame = Tkinter.Frame(self.top)
-        bottom_frame.pack(side='bottom', fill='both', expand=False,
-                          ipadx=3, ipady=3)
-        if kw.separator:
-            separator = Tkinter.Frame(self.top, relief="sunken",
-                    height=2, width=2, borderwidth=1)
-            separator.pack(side='bottom', fill='x')
-        top_frame = Tkinter.Frame(self.top)
-        top_frame.pack(side='top', fill='both', expand=True)
-        return top_frame, bottom_frame
-        '''
-
-    '''
-    def createBitmaps(self, frame, kw):
-        if kw.bitmap:  # in ("error", "info", "question", "warning")
-            img = self.img.get(kw.bitmap)
-            b = Tkinter.Label(frame, image=img)
-            b.pack(side=kw.bitmap_side,
-                   padx=kw.bitmap_padx, pady=kw.bitmap_pady)
-        elif kw.image:
-            b = Tkinter.Label(frame, image=kw.image)
-            b.pack(side=kw.image_side, padx=kw.image_padx, pady=kw.image_pady)
-    '''
-
-    '''
-    def createButtons(self, frame, kw):
-        button = -1
-        column = 0
-        # padx, pady = kw.get("buttonpadx", 10), kw.get("buttonpady", 10)
-        focus = None
-        max_len = 0
-        for s in kw.strings:
-            if isinstance(s, tuple):
-                s = s[0]
-            if s:
-                # if os.name == 'posix':
-                #    s = s.replace('...', '.')
-                s = s.replace('&', '')
-                max_len = max(max_len, len(s))
-            # print s, len(s)
-        # if max_len > 12 and WIN_SYSTEM == 'x11':
-        #     button_width = max_len
-        # elif max_len > 9:
-        #     button_width = max_len + 1
-        # elif max_len > 6:
-        #     button_width = max_len + 2
-        # else:
-        #     button_width = 8
-        # print 'button_width =', button_width
-        #
-        #
-        for s in kw.strings:
-            xbutton = button = button + 1
-            if isinstance(s, tuple):
-                assert len(s) == 2
-                button = int(s[1])
-                s = s[0]
-            if s is None:
-                continue
-            # accel_indx = s.find('&')
-            s = s.replace('&', '')
-            if button < 0:
-                # b = Tkinter.Button(frame, text=s, state="disabled")
-                button = xbutton
-            else:
-                # b = Tkinter.Button(frame, text=s, default="normal",
-                #                   command=(lambda self=self,
-                #                   button=button: self.mDone(button)))
-                b = Button(text=s, size_hint=(1, 1))
-                frame.add_widget(b)
-                # if button == kw.default:
-                #    focus = b
-                #    focus.config(default="active")
-            # self.buttons.append(b)
-            #
-            # b.config(width=button_width)
-            # if accel_indx >= 0:
-                # key accelerator
-            #    b.config(underline=accel_indx)
-            #    key = s[accel_indx]
-            #    self.accel_keys[key.lower()] = button
-            #
-#             img = None
-#             if self.button_img:
-#                 img = self.button_img.get(s)
-#             b.config(compound='left', image=img)
-            column += 1
-            # b.grid(column=column, row=0, sticky="ns", padx=padx, pady=pady)
-        # if focus is not None:
-            # l = (lambda event=None,
-            #   selScrollViewf=self, button=kw.default: self.mDone(button))
-            # bind(self.top, "<Return>", l)
-            # bind(self.top, "<KP_Enter>", l)
-        # frame.columnconfigure(0, weight=1)
-        # frame.columnconfigure(99, weight=1)
-        return focus
-    '''
 
 
 # ************************************************************************
